@@ -39,9 +39,13 @@ class FormRenderer(DjangoTemplates):
         )
         return context
 
-    def _amend_fieldset(self, context):
+    def X_amend_dual_selector(self, context):
         context.update(
-            css_classes=self.fieldset_css_classes,
+            wrapper_classes='dj-dual-selector',
+            column_left_classes='left-column',
+            column_center_classes='control-column',
+            control_panel_classes='control-panel',
+            column_right_classes='right-column',
         )
         return context
 
@@ -71,6 +75,12 @@ class FormRenderer(DjangoTemplates):
         context['widget']['inlined_options'] = max_options <= self.max_options_per_line
         return context
 
+    def _amend_fieldset(self, context):
+        context.update(
+            css_classes=self.fieldset_css_classes,
+        )
+        return context
+
     def _amend_collection(self, context):
         context.update({
             'add_collection_button': 'formset/default/buttons/add_collection.html',
@@ -86,6 +96,7 @@ class FormRenderer(DjangoTemplates):
         'django/forms/widgets/radio.html': _amend_multiple_input,
         'formset/default/fieldset.html': _amend_fieldset,
         'formset/default/collection.html': _amend_collection,
+        #'formset/default/widgets/dual_selector.html': _amend_dual_selector,
     }
 
     def render(self, template_name, context, request=None):
